# pyrtz2

Analysis of AFM force curves in Python.

Developed at Georgia Institute of Technology

# Installation
pyrtz2 is on PyPI. Install using pip (Python version >= 3.10.0 is required)

```
pip install pyrtz2
```

Please see the example folder. To run the HTML dash app interface simply use:

```
from pyrtz2 import app
app.run()
```

These options are under development:
- Show Fits
- Download Image Data
- Download Experiment
